@@ -3,16 +3,26 @@ import math
 from typing import Any, Dict, List, Optional, Union
 from ruamel.yaml import YAML
 from ruamel.yaml.error import YAMLError
+from ansibler.platforms.platform_map import (
+    parse_platform_map,
+    map_to_galaxy_supported_platforms
+)
 from ansibler.utils.files import create_folder_if_not_exists
 
 
-def populate_platforms(json_file: Optional[str] = "./ansibler.json") -> None:
+def populate_platforms(
+    json_file: Optional[str] = "./ansibler.json",
+    platform_map_file: Optional[str] = None
+) -> None:
     # TODO: TESTS
     # Read from package.json
     data = read_json_file(json_file)
     compatibility = data.get("compatibility_matrix", [])
     compatibility = [] if len(compatibility) <= 1 else compatibility[1:]
 
+    # Parse Platform Map
+    platform_map = parse_platform_map(platform_map_file)
+
     # Generate platforms value
     platforms, supported, unsupported = [], [], []
     for platform in compatibility:
@@ -39,6 +49,9 @@ def populate_platforms(json_file: Optional[str] = "./ansibler.json") -> None:
     platforms = join_platforms(platforms)
 
     galaxy_info["platforms"] = platforms if platforms else None
+    galaxy_info["platforms"] = map_to_galaxy_supported_platforms(
+        galaxy_info["platforms"], platform_map
+    )
     meta_main["galaxy_info"] = galaxy_info
 
     # Save
@@ -96,7 +109,7 @@ def merge_platforms(
 
     for old_platform in old_platforms:
         name = old_platform.get("name", None)
-        versions = list(set(platform.get("versions", [])))
+        versions = old_platform.get("versions", [])
 
         if name is None:
             continue
@@ -109,7 +122,11 @@ def merge_platforms(
                 for current_platform in res:
                     cur_name = current_platform.get("name")
                     if cur_name == name:
-                        cur_versions = current_platform.get("versions", [])
+                        cur_versions = [
+                            get_formatted_os_version(name, v)
+                            for v in current_platform.get("versions", [])
+                        ]
+
                         cur_versions.append(
                             get_formatted_os_version(name, version))
                         supported.append(os)
